pub struct LogParser { /* private fields */ }Implementations
Sourceimpl LogParser
impl LogParser
pub fn from_path<P: AsRef<Path>>(path: P) -> Result<Self, ParseError>
pub fn iter(&self) -> LogIterator<'_> ⓘ
Sourcepub fn par_iter(
&self,
) -> impl ParallelIterator<Item = Result<Sqllog<'_>, ParseError>> + '_
pub fn par_iter( &self, ) -> impl ParallelIterator<Item = Result<Sqllog<'_>, ParseError>> + '_
Returns a Rayon parallel iterator over all log records.
Splits the file into CPU-count chunks at record boundaries and processes each chunk on a separate thread.